@@ -38,12 +38,12 @@ class GzipCompressionWrapper(io.RawIOBase):
         return size
 
 
-class CompressStorageMixin():
+class CompressStorageMixin:
     def _compress_content(self, content):
         """Gzip a given string content."""
         return GzipCompressionWrapper(content)
 
 
-class CompressedFileMixin():
+class CompressedFileMixin:
     def _decompress_file(self, mode, file, mtime=0.0):
         return GzipFile(mode=mode, fileobj=file, mtime=mtime)
