@@ -502,6 +502,15 @@ class S3StorageTests(TestCase):
             Key="file.txt",
         )
 
+    def test_storage_exists_ssec(self):
+        params = {"SSECustomerKey": "xyz", "CacheControl": "never"}
+        self.storage.get_object_parameters = lambda name: params
+        self.storage.file_overwrite = False
+        self.assertTrue(self.storage.exists("file.txt"))
+        self.storage.connection.meta.client.head_object.assert_called_with(
+            Bucket=self.storage.bucket_name, Key="file.txt", SSECustomerKey="xyz"
+        )
+
     def test_storage_exists_false(self):
         self.storage.connection.meta.client.head_object.side_effect = ClientError(
             {"Error": {}, "ResponseMetadata": {"HTTPStatusCode": 404}},
@@ -710,6 +719,14 @@ class S3StorageTests(TestCase):
         self.storage.url("test_name")
         self.storage.unsigned_connection.meta.client.generate_presigned_url.assert_called_once()
 
+    def test_url_protocol(self):
+        self.assertFalse(hasattr(settings, "AWS_S3_URL_PROTOCOL"))
+        self.assertEqual(self.storage.url_protocol, "https:")
+
+        with override_settings(AWS_S3_URL_PROTOCOL=None):
+            storage = s3.S3Storage()
+            self.assertEqual(storage.url_protocol, "https:")
+
     @mock.patch("storages.backends.s3.datetime")
     def test_storage_url_custom_domain_signed_urls(self, dt):
         key_id = "test-key"
